]> git.saurik.com Git - redis.git/commitdiff
rename ziplistDelete to ziplistDeleteRange
authorPieter Noordhuis <pcnoordhuis@gmail.com>
Fri, 21 May 2010 13:44:47 +0000 (15:44 +0200)
committerPieter Noordhuis <pcnoordhuis@gmail.com>
Sat, 29 May 2010 19:10:15 +0000 (21:10 +0200)
ziplist.c

index 5c8221876a7497e02ccb0bfe6e494c3a272e2759..c1278b65234888b95494e032afb49b0fcd47a448 100644 (file)
--- a/ziplist.c
+++ b/ziplist.c
@@ -130,8 +130,8 @@ unsigned char *ziplistNext(unsigned char *p, unsigned char **entry, unsigned int
     return p;
 }
 
-/* Delete one or more entries from the ziplist. */
-unsigned char *ziplistDelete(unsigned char *zl, unsigned int index, unsigned int num) {
+/* Delete a range of entries from the ziplist. */
+unsigned char *ziplistDeleteRange(unsigned char *zl, unsigned int index, unsigned int num) {
     unsigned char *p, *first = ziplistIndex(zl, index);
     unsigned int i, deleted = 0, totlen, newlen;
     for (p = first, i = 0; *p != ZIP_END && i < num; i++) {
@@ -245,35 +245,35 @@ int main(int argc, char **argv) {
     printf("Delete inclusive range 0,0:\n");
     {
         zl = createList();
-        zl = ziplistDelete(zl, 0, 1);
+        zl = ziplistDeleteRange(zl, 0, 1);
         ziplistRepr(zl);
     }
 
     printf("Delete inclusive range 0,1:\n");
     {
         zl = createList();
-        zl = ziplistDelete(zl, 0, 2);
+        zl = ziplistDeleteRange(zl, 0, 2);
         ziplistRepr(zl);
     }
 
     printf("Delete inclusive range 1,2:\n");
     {
         zl = createList();
-        zl = ziplistDelete(zl, 1, 2);
+        zl = ziplistDeleteRange(zl, 1, 2);
         ziplistRepr(zl);
     }
 
     printf("Delete with start index out of range:\n");
     {
         zl = createList();
-        zl = ziplistDelete(zl, 5, 1);
+        zl = ziplistDeleteRange(zl, 5, 1);
         ziplistRepr(zl);
     }
 
     printf("Delete with num overflow:\n");
     {
         zl = createList();
-        zl = ziplistDelete(zl, 1, 5);
+        zl = ziplistDeleteRange(zl, 1, 5);
         ziplistRepr(zl);
     }